@@ -70,9 +70,11 @@ gsh_handle_add_arguments(struct GSH * gsh, int argc, char **argv, int *counter)
 		gsh_count(argc, counter);
 		gsh_add_label(gsh, argv[(*counter)]);
 		break;
+
 	case 'P':
 		add_piped_generic(gsh, &add_piped_text);
 		break;
+
 	case 'p':
 		add_piped_generic(gsh, &add_piped_label);
 		break;
@@ -80,6 +82,12 @@ gsh_handle_add_arguments(struct GSH * gsh, int argc, char **argv, int *counter)
 	case 'r': /* Force creation of a new row.  */
 		gsh_new_row(gsh);
 		break;
+
+	case 's': /* Add a shell.  */
+		gsh_count(argc, counter);
+		gsh_setup_terminal(gsh, argv[*counter]);
+		break;
+
 	case 't':
 		if (argc != *counter)
 			gsh_count(argc, counter);
@@ -98,5 +106,8 @@ gsh_handle_add_arguments(struct GSH * gsh, int argc, char **argv, int *counter)
 	case 'w':
 		add_new_window(gsh);
 		break;
+
+	default:
+		ARWARN("invalid add option");
 	}
 }
