@@ -17,8 +17,7 @@
 
   You should have received a copy of the GNU General Public License
   along with AntiRight; if not, write to the Free Software
-  Foundation, Inc., 51 Franklin Street, Fifth Floor, 
-  	Boston, MA  02110-1301  USA
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 #include "gtkshell.h"
@@ -29,7 +28,7 @@ setup_label(GtkWidget *widget, char *command);
 static void
 create_label_in_menu_item(GtkWidget * widget, char * formatted)
 {
-	/*@shared@*/GtkWidget * label;
+	GtkWidget * label;
 
 	label = gtk_label_new(formatted);
 	gtk_container_add(GTK_CONTAINER(widget), label);
@@ -39,7 +38,7 @@ create_label_in_menu_item(GtkWidget * widget, char * formatted)
 static void
 setup_label(GtkWidget *widget, char *command)
 {
-	/*@only*/gchar *formatted;
+	gchar *formatted;
 
 	formatted = antiright_beautified_label(command);
 
@@ -48,7 +47,7 @@ setup_label(GtkWidget *widget, char *command)
 	else
 		gtk_button_set_label(GTK_BUTTON(widget), formatted);
 
-	g_free(formatted);
+	free(formatted);
 }
 
 static struct GSH_CBData *
@@ -57,8 +56,7 @@ setup_callback_data(struct GSH * gsh, char * command)
 	struct GSH_CBData * cb;
 
 	/* Allocate and initialize elements.  */
-	cb = (struct GSH_CBData *) 
-		xmalloc(sizeof(struct GSH_CBData));
+	cb = (struct GSH_CBData *) xmalloc(sizeof(struct GSH_CBData));
 
 	cb->gsh = gsh;
 	cb->data = command;	/* command from argv, literal, or
@@ -75,7 +73,7 @@ setup_callback(struct GSH * gsh, char * command)
 
 	cb=setup_callback_data(gsh, command);
 
-	ARIFB(GTK_IS_MENU_ITEM(gsh->button))
+	if(GTK_IS_MENU_ITEM(gsh->button))
 	{
 		(void) g_signal_connect(G_OBJECT(gsh->button), 
 				"activate", G_CALLBACK(system_cb), cb);
@@ -83,10 +81,10 @@ setup_callback(struct GSH * gsh, char * command)
 	}
 	else if((gsh->bflags & GSH_MENU_BUTTON) != GSH_MENU_BUTTON)
 	{
+		/* @null@ */
 		(void) g_signal_connect(G_OBJECT(gsh->button), 
 				"clicked", G_CALLBACK(system_cb), cb);
 	}
-	/* If the button launches a menu, do not add a system_cb.  */
 	else if((gsh->bflags & GSH_MENU_BUTTON) == GSH_MENU_BUTTON)
 		gsh->bflags ^= GSH_MENU_BUTTON;
 
@@ -96,12 +94,7 @@ static void
 create_button(struct GSH * gsh)
 {
 	if(!GTK_IS_MENU(gsh->rows.v))
-	{
 		gsh->button = gtk_button_new();
-		/* For now, we only do drag 
-		 * and drop with regular buttons.  */
-		gsh_setup_drag_drop(gsh, gsh->button);
-	}
 	else
 		gsh->button = gtk_menu_item_new();
 
@@ -119,6 +112,7 @@ gsh_command_button(struct GSH * gsh, char *command)
 
 	create_button(gsh);
 	setup_label(gsh->button, command);
+	gsh_setup_drag_drop(gsh, gsh->button);
 	setup_callback(gsh, command);
 	gsh_manage_unexpanded(gsh, gsh->button);
 
