@@ -30,9 +30,9 @@ enum
 	TARGET_STRING
 };
 
-static const GtkTargetEntry target_list[] =
+static GtkTargetEntry target_list[] =
 {
-	{(gchar*)"text/plain", 0, TARGET_STRING}
+	{(gchar *)"text/plain", 0, TARGET_STRING}
 };
 
 static guint n_targets = G_N_ELEMENTS(target_list);
