@@ -27,8 +27,26 @@
 #include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <vte/vte.h>
+#include <unistd.h>
+
 #include "../libantiright/library.h"
 
+#ifndef YYFILE
+#include "y.tab.h"
+#endif /* !YYFILE */
+
+int
+yyparse();
+
+void
+gsh_free_parse_memory();
+
+void
+gsh_append_arg(char *);
+
 struct GSH_Rows
 {
 	GtkWidget *h;
@@ -43,6 +61,13 @@ struct GSH_Updater
 	/*@null@*/ GSList *list;
 };
 
+struct GSH_Terminal
+{
+	GtkWidget * widget;
+	gchar * font;
+	gchar * script;
+};
+
 #define GSH_NONE		0
 #define GSH_SCROLL 		1
 #define GSH_CBEXIT 		2
@@ -51,14 +76,20 @@ struct GSH_Updater
 #define GSH_PROMPT_ECHOES	16
 #define GSH_FRAMED_LABELS	32
 #define GSH_MENU_BUTTON		64
+#define GSH_NO_BASE_FRAME	128
+
+#define GSH_FLAG(flag) ((gsh->bflags & flag) == flag)
+#define GSH_SET(flag) gsh->bflags |= flag
+#define GSH_UNSET(flag) gsh->bflags &= ~flag
 
 struct GSH
 {
-	/*@shared@*/ GtkWidget *window;
-	/*@shared@*/ GtkWidget *scrolled_window;
+	GtkWidget *window;
+	GtkWidget *scrolled_window;
 	struct GSH_Rows rows;
 	struct GSH_Updater update;
-	/*@shared@*/GtkWidget *button;
+	struct GSH_Terminal terminal;
+	GtkWidget *button;
 	/*@null@*/ gchar *geometry;
 	guint bflags;
 };
@@ -83,6 +114,7 @@ struct GSH
 #include "font.h"
 #include "dragdrop.h"
 #include "image_button.h"
+#include "terminal.h"
 
 void
 gsh_stack_init(struct GSH * gsh, int *argc, char ***argv);
@@ -99,4 +131,4 @@ gsh_GSH(struct GSH * gsh);
 struct GSH *
 gsh_new_GSH();
 
-#endif /* !GSH_GTKSHELL_H */
+#endif
