@@ -42,9 +42,10 @@ generic_image_button(struct GSH * gsh, char *command,
 		hrow=gtk_hbox_new(FALSE, 2);
 		gtk_container_add(GTK_CONTAINER(gsh->button), hrow);
 		gtk_widget_show(hrow);
-		gtk_container_add(GTK_CONTAINER(hrow), image);
+		gtk_box_pack_start(GTK_BOX(hrow), image, FALSE, FALSE, 0);
 		gtk_widget_show(image);
 		gtk_container_add(GTK_CONTAINER(hrow), label);
+
 		gtk_widget_show(label);
 	}
 }
