@@ -24,24 +24,7 @@
 #define GSH_IMAGE_BUTTON_H
 
 void
-gsh_image_button(struct GSH * gsh, char *command, char *filename);
-
-void
-gsh_handle_add_image_button(struct GSH * gsh, int argc, 
-			    char **argv, int *counter);
-
-void
-gsh_handle_add_unlabeled_image_button(struct GSH * gsh, int argc, 
-				      char **argv, int *counter);
-
-void
-gsh_stock_image_button(struct GSH * gsh, char *command, 
-		       char *stock_id);
-
-void
-gsh_handle_add_stock_button(struct GSH * gsh, int argc, char **argv, 
-			    int * counter);
-
+gsh_image_button(struct GSH * gsh, char *command, char *name);
 
 #endif /* GSH_IMAGE_BUTTON_H */
 
