@@ -25,9 +25,10 @@
 int
 main(int argc, char **argv)
 {
+	//Store application structure on stack.
 	struct GSH gsh;
 
-	//Store application structure on stack.
+	gsh.terminal.script=NULL;
 
 	gsh_stack_init(&gsh, &argc, &argv);
 
@@ -41,10 +42,17 @@ main(int argc, char **argv)
 
 	gsh_setup_containers(&gsh);
 	gsh_parse_arguments(&gsh, argc, argv);
+	gsh_setup_base_container(&gsh);
 
 	gsh_check_and_set_geometry(&gsh);
 	gtk_widget_show(gsh.window);
 	gtk_main();
 
+	if(gsh.terminal.script != NULL)
+	{
+		unlink(gsh.terminal.script);
+		free(gsh.terminal.script);
+	}
+
 	return (EXIT_SUCCESS);
 }
